import cyDisp as cyDisp
import numpy as np

def calDisp(thickness, vp, vs, rho, periods,dc0=0.005,domega=0.0001,wave='rayleigh', mode=1, velocity='phase', flat_earth=True,ar=6370.0,parameter='vp',smoothN=1):
    '''
    velocity: phase group kernel kernelGroup
    wave: love rayleigh
    parameter: vp vs rho thickness
    domega: for cal group and delta_omega=omega*domega
    dc0: is for search phase velocity and cal sensitive kernel
    mode: from 1
    '''
    if velocity == 'phase':
        return np.array(cyDisp.calDisp(thickness.astype(np.float64), vp.astype(np.float64), vs.astype(np.float64),rho.astype(np.float64),periods.astype(np.float64),dc0=dc0,isR=(wave =='rayleigh'),isFlat=flat_earth,mode=mode,ar=ar))
    if velocity == 'group':
        return np.array(cyDisp.group(thickness.astype(np.float64), vp.astype(np.float64), vs.astype(np.float64),rho.astype(np.float64),periods.astype(np.float64),dc0=dc0,domega=domega,isR=(wave =='rayleigh'),isFlat=flat_earth,mode=mode,ar=ar))
    if velocity =='kernel':
        return np.array(cyDisp.kernel(thickness.astype(np.float64), vp.astype(np.float64), vs.astype(np.float64),rho.astype(np.float64),periods.astype(np.float64),dc0=dc0,domega=domega,isR=(wave =='rayleigh'),isFlat=flat_earth,mode=mode,ar=ar,isP=(parameter=='vp'),isS=(parameter=='vs'),isRho=(parameter=='rho'),isD=(parameter=='thickness')))
    if velocity =='kernelGroup':
        return np.array(cyDisp.kernelGroup(thickness.astype(np.float64), vp.astype(np.float64), vs.astype(np.float64),rho.astype(np.float64),periods.astype(np.float64),dc0=dc0,domega=domega,isR=(wave =='rayleigh'),isFlat=flat_earth,mode=mode,ar=ar,isP=(parameter=='vp'),isS=(parameter=='vs'),isRho=(parameter=='rho'),isD=(parameter=='thickness'),smoothN=smoothN))


import numpy as np  
# 不用numpy不加这行
from distutils.core import setup  
# 必须部分
from distutils.extension import Extension  
# 必须部分
from Cython.Distutils import build_ext  
# 必须部分

ext_modules = [Extension("cyDisp", ["cyDisp.pyx"])]#, include_dirs=[np.get_include()]),]
# filename就是你的.pyx文件前面的名字，注意后面中括号和这里的名字“最好”一致，不然有些时候会报错。
# 调用numpy就添加include_dirs参数，不然可以去掉

setup(name="cyDisp", cmdclass={"build_ext": build_ext}, ext_modules=ext_modules)
# 这个name随便写，其他的格式不能变
# （更新一下，python3.8的时候这个名字要和上面的filename一样）

